package com.muyu.server.mqtt;

import com.alibaba.fastjson.JSONObject;

import com.muyu.common.kafka.constants.KafkaConstants;
import com.muyu.domain.CarMessage;
import com.muyu.server.service.CarMessageService;
import jakarta.annotation.PostConstruct;
import org.apache.kafka.clients.producer.KafkaProducer;
import org.apache.kafka.clients.producer.ProducerRecord;
import org.eclipse.paho.client.mqttv3.*;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.CompletableFuture;


@Component
public class Demo {
    @Resource
    private CarMessageService service;
    @Resource
    private KafkaProducer<String, String> kafkaProducer;
    @PostConstruct
    public void  test() {

        String topic        = "vehicle";
        String content      = "Message from MqttPublishSample";
        int qos             = 2;
        String broker       = "tcp://106.15.136.7:1883";
        String clientId     = "JavaSample";

        try {
            // 第三个参数为空，默认持久化策略
            MqttClient sampleClient = new MqttClient(broker, clientId);
            MqttConnectOptions connOpts = new MqttConnectOptions();
            connOpts.setCleanSession(true);
            System.out.println("Connecting to broker: "+broker);
            sampleClient.connect(connOpts);
            sampleClient.subscribe(topic,0);
            sampleClient.setCallback(new MqttCallback() {
                // 连接丢失
                @Override
                public void connectionLost(Throwable throwable) {

                }
                // 连接成功
                @Override
                public void messageArrived(String s, MqttMessage mqttMessage) throws Exception {

                    List<CarMessage> list= service.selectCarMessageList(1,2);
                    String str = new String( mqttMessage.getPayload() );
                    System.out.println(str);
                    String[] test = str.split(" ");
                    String[] results = new String[list.size()];
                    List<CompletableFuture<String>> futures = new ArrayList<>();
                    for (CarMessage carmsg : list) {
                        futures.add(CompletableFuture.supplyAsync(() -> {
                            int startIndex = Integer.parseInt(String.valueOf(carmsg.getCarMessageStartIndex())) - 1;
                            int endIndex = Integer.parseInt(String.valueOf(carmsg.getCarMessageEndIndex()));
                            StringBuilder hexBuilder = new StringBuilder();
                            for (int j = startIndex; j < endIndex; j++) {
                                hexBuilder.append(test[j]);
                            }
                            // 创建16进制的对象
                            String hex = hexBuilder.toString();
                            // 转橙字符数组
                            char[] result = new char[hex.length() / 2];
                            for (int x = 0; x < hex.length(); x += 2) {
                                // 先转十进制
                                int high = Character.digit(hex.charAt(x), 16);
                                // 转二进制
                                int low = Character.digit(hex.charAt(x + 1), 16);
                                // 转字符
                                result[x / 2] = (char) ((high << 4) + low);
                            }
                            return new String(result);
                        }));
                    }
                    for (int i = 0; i < futures.size(); i++) {
                        results[i] = futures.get(i).get();
                    }
                    String jsonString = JSONObject.toJSONString( results );
                    ProducerRecord<String, String> producerRecord = new ProducerRecord<>( KafkaConstants.KafkaTopic, jsonString);
                    kafkaProducer.send(producerRecord);
                }
                // 接收信息
                @Override
                public void deliveryComplete(IMqttDeliveryToken iMqttDeliveryToken) {

                }
            });
        } catch(MqttException me) {
            System.out.println("reason "+me.getReasonCode());
            System.out.println("msg "+me.getMessage());
            System.out.println("loc "+me.getLocalizedMessage());
            System.out.println("cause "+me.getCause());
            System.out.println("excep "+me);
            me.printStackTrace();
        }
    }

}
